from __future__ import unicode_literals

import warnings

warnings.warn('germanium.anotations module is deprecated, use annotations instead.', DeprecationWarning, stacklevel=2)

from germanium.annotations import *  # NOQA
